@@ -1,23 +1,22 @@
-from os import environ
+from os import environ, path
 from sys import exit
 from ruamel.yaml import YAML
 import json
-from odin_logger import OdinLogger as logger
+from pyodin.odin_logger import OdinLogger as logger
 from time import time
 
-
 class Odin:
     def __init__(self, config="job.yml", test=False):
-        self.config = config
+        pathway = path.abspath(".")
+        self.config = pathway + "/" + config
         try: 
             with open(self.config,"r") as config:
                 configR = config.read()
             data = YAML().load(configR)
+            self.id = data["job"]["id"]
+            self.timestamp = time()
         except Exception as e:
             print(e)
-        self.id = data["job"]["id"]
-        self.timestamp = time()
-
         if 'ODIN_EXEC_ENV' in environ or test != False:
             self.ENV_CONFIG = True
         else:
@@ -35,4 +34,4 @@ class Odin:
     def result(self, desc, status):
         if self.ENV_CONFIG:
             logger.log("result", desc, status, self.id, self.timestamp)
-        exit(0)
\ No newline at end of file
+        exit(0)
